package com.hai.order.service.impl;

import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.dao.HighOrderRefundMapper;
import com.hai.entity.HighChildOrder;
import com.hai.entity.HighOrder;
import com.hai.entity.HighOrderRefund;
import com.hai.entity.HighOrderRefundExample;
import com.hai.order.service.OrderRefundService;
import com.hai.order.service.OrderService;
import com.hai.order.type.OrderChildStatus;
import com.hai.order.type.OrderPayType;
import com.hai.order.type.OrderRefundStatus;
import com.hai.order.type.OrderStatus;
import com.hai.order.utils.OrderUtil;
import com.hai.service.HighUserService;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @className: OrderRefundServiceImpl
 * @author: HuRui
 * @date: 2022/9/1
 **/
@Service("orderRefundService")
public class OrderRefundServiceImpl implements OrderRefundService {

    @Resource
    private HighOrderRefundMapper orderRefundMapper;

    @Resource
    private HighUserService userService;

    @Resource
    private OrderService orderService;

    @Override
    public HighOrder createOrderRefund(HighOrder order, String remarks) throws Exception {
        // 退款订单号
        String refundOrderNo = OrderUtil.generateRefundOrderNo();

        for (HighChildOrder orderChild : order.getHighChildOrderList()) {
            // 创建退款记录
            HighOrderRefund orderRefund = createOrderChildRefund(orderChild, refundOrderNo, orderChild.getSaleCount(), remarks);
            orderChild.setSurplusRefundNum(orderChild.getSurplusRefundNum() - orderRefund.getRefundGoodsNum());
            orderChild.setSurplusRefundPrice(orderChild.getSurplusRefundPrice().subtract(orderRefund.getRefundPrice()));
            orderChild.setSurplusRefundIntegral(orderChild.getSurplusRefundIntegral() - orderRefund.getRefundIntegral());
            if (orderChild.getSurplusRefundNum() == 0) {
                orderChild.setChildOrderStatus(OrderChildStatus.STATUS6.getNumber());
            }
        }
        return order;
    }

    @Override
    public HighOrderRefund createOrderChildRefund(HighChildOrder orderChild,String refundNo,Integer refundGoodsCount, String remarks) throws Exception {
        if (!orderChild.getChildOrderStatus().equals(OrderChildStatus.STATUS2.getNumber())
            && !orderChild.getChildOrderStatus().equals(OrderChildStatus.STATUS3.getNumber())){
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "子订单状态错误");
        }
        if (orderChild.getSurplusRefundIntegral() <= 0
                && orderChild.getSurplusRefundPrice().compareTo(new BigDecimal("0")) <= 0) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "子订单余额不足");
        }
        // 判断剩余可退商品数量
        if (orderChild.getSurplusRefundNum() < refundGoodsCount) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "退款商品数量超过剩余退款数量");
        }
        // 交易订单
        HighOrder order = orderService.getOrderDetailByNo(orderChild.getOrderNo());
        if (order == null) {
            throw ErrorHelp.genException(SysCode.System, ErrorCode.COMMON_ERROR, "交易订单不存在");
        }
        // 退款金额   剩余退款金额 / 退款数量
        BigDecimal refundPrice = orderChild.getSurplusRefundPrice().divide(new BigDecimal(refundGoodsCount.toString())).setScale(2, BigDecimal.ROUND_DOWN);
        // 退款积分   剩余退款积分 / 退款数量
        Integer refundIntegral = new BigDecimal(orderChild.getSurplusRefundIntegral().toString()).divide(new BigDecimal(refundGoodsCount.toString()), 0, BigDecimal.ROUND_DOWN).intValue();

        HighOrderRefund orderRefund = new HighOrderRefund();
        orderRefund.setOrderId(orderChild.getOrderId());
        orderRefund.setOrderNo(orderChild.getOrderNo());
        orderRefund.setOrderChildId(orderChild.getId());
        orderRefund.setOrderChildNo(orderChild.getChildOrderNo());
        orderRefund.setMemId(orderChild.getMemId());
        orderRefund.setMemName(orderChild.getMemPhone());
        orderRefund.setMemPhone(orderChild.getMemPhone());
        orderRefund.setGoodsType(orderChild.getGoodsType());
        orderRefund.setGoodsId(orderChild.getGoodsId());
        orderRefund.setGoodsName(orderChild.getGoodsName());
        orderRefund.setGoodsDesc(orderChild.getGoodsDesc());
        orderRefund.setGoodsImg(orderChild.getGoodsImg());
        orderRefund.setGoodsSpecName(orderChild.getGoodsSpecName());
        orderRefund.setGoodsCount(orderChild.getSaleCount());
        orderRefund.setRefundOrder(refundNo==null?OrderUtil.generateRefundOrderNo():refundNo);
        orderRefund.setRefundGoodsNum(refundGoodsCount);
        orderRefund.setReturnTotalPrice(refundPrice.add(new BigDecimal(refundIntegral).divide(new BigDecimal("100"))));
        orderRefund.setRefundPrice(refundPrice);
        orderRefund.setRefundIntegral(refundIntegral);
        orderRefund.setRefundRemark(remarks);
        orderRefund.setRefundStatus(OrderRefundStatus.STATUS1.getNumber());
        orderRefund.setCreateTime(new Date());
        orderRefund.setUpdateTime(new Date());
        orderRefundMapper.insert(orderRefund);
        return orderRefund;
    }

    @Override
    public List<HighOrderRefund> getRefundOrderList(Map<String, Object> param) {
        HighOrderRefundExample example = new HighOrderRefundExample();
        HighOrderRefundExample.Criteria criteria = example.createCriteria();

        if (StringUtils.isNotBlank(MapUtils.getString(param, "orderNo"))) {
            criteria.andOrderNoLike("%"+MapUtils.getString(param, "orderNo")+"%");
        }

        if (StringUtils.isNotBlank(MapUtils.getString(param, "orderChildNo"))) {
            criteria.andOrderChildNoEqualTo(MapUtils.getString(param, "orderChildNo"));
        }

        if (StringUtils.isNotBlank(MapUtils.getString(param, "memPhone"))) {
            criteria.andMemPhoneEqualTo(MapUtils.getString(param, "memPhone"));
        }

        if (MapUtils.getInteger(param, "goodsType") != null) {
            criteria.andGoodsTypeEqualTo(MapUtils.getInteger(param, "goodsType"));
        }

        if (StringUtils.isNotBlank(MapUtils.getString(param, "goodsName"))) {
            criteria.andGoodsNameLike("%"+MapUtils.getString(param, "goodsName")+"%");
        }

        if (StringUtils.isNotBlank(MapUtils.getString(param, "goodsName"))) {
            criteria.andGoodsNameLike("%"+MapUtils.getString(param, "goodsName")+"%");
        }

        example.setOrderByClause("create_time desc");
        return orderRefundMapper.selectByExample(example);
    }

    /**
     * 金额退回用户
     * @param orderNo          订单号
     * @param refundPrice      退款金额
     * @param refundIntegral   退款积分
     */
    public void refundPrice(String orderNo,BigDecimal refundPrice,Integer refundIntegral) throws Exception {

    }
}
